==> ordering-core-react-0.3.1.tgz: package/lib/esm/AuthWrapper.js <==
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import React, { Fragment, useContext, useEffect, useState } from "react";
import AuthContext from "./AuthContext";
import ConfigContext from "./ConfigContext";
import * as orderingCore from "@orderingstack/ordering-core";
const refreshStorageHandler = {
    getRefreshToken: (tenant) => {
        return (window.localStorage.getItem(`orderingstack_${tenant}_refreshToken`) || "");
    },
    setRefreshToken: (tenant, token) => {
        window.localStorage.setItem(`orderingstack_${tenant}_refreshToken`, token);
    },
    clearRefreshToken: (tenant) => {
        window.localStorage.removeItem(`orderingstack_${tenant}_refreshToken`);
    },
};
export default function AuthWrapper(props) {
    const _configContext = useContext(ConfigContext);
    if (!_configContext) {
        return React.createElement(Fragment, null, "Configuration shoud be provided");
    }
    const config = _configContext;
    const [auth, setAuth] = useState({
        loggedIn: false,
        UUID: "",
    });
    function onSignOut() {
        console.log("--- log out ----");
        setAuth({ loggedIn: false, UUID: "" });
        orderingCore.clearAuthData(config.tenant, refreshStorageHandler);
    }
    function hasValidRoles(acceptedRolesArray, roles) {
        if (!acceptedRolesArray || acceptedRolesArray.length === 0) {
            return true;
        }
        const authorities = roles.map((r) => r.role);
        const rolesIntersection = acceptedRolesArray.filter((value) => authorities.includes(value));
        const isAuthorized = rolesIntersection.length > 0; //authorities.includes(role);
        return isAuthorized;
    }
    function getUserData(baseUrl, authProvider, setAuth) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const { UUID, token } = yield authProvider();
                if (token) {
                    const userData = yield orderingCore.getLoggedUserData(baseUrl, token);
                    if (!hasValidRoles(props.roles, userData.roles)) {
                        console.log("--- USER HAS NO REQUIRED ROLES ----- ");
                        onSignOut();
                    }
                    setAuth({
                        loggedIn: true,
                        email: userData.login,
                        UUID: UUID,
                        authProvider: authProvider,
                        signOut: onSignOut,
                    });
                }
            }
            catch (err) {
                onSignOut();
            }
        });
    }
    useEffect(() => {
        //console.log("AutWrapper init --- ");
        const authProvider = orderingCore.createAuthDataProvider({
            BASE_URL: config.baseUrl,
            TENANT: config.tenant,
            BASIC_AUTH: config.basicAuth,
            anonymousAuth: config.anonymousOnInit,
        }, refreshStorageHandler, false);
        try {
            const refreshToken = new URLSearchParams(window.location.search).get("refreshToken");
            if (refreshToken) {
                refreshStorageHandler.setRefreshToken(config.tenant, refreshToken);
            }
        }
        catch (e) {
            console.warn(e);
        }
        getUserData(config.baseUrl, authProvider, setAuth);
        window.addEventListener("message", function (event) {
            if (event.origin !== config.baseUrl)
                return;
            const authData = event.data;
            console.log(authData);
            if (authData.UUID === "") {
                setAuth({ loggedIn: false, UUID: "" });
            }
            else {
                orderingCore.setAuthData(config.tenant, {
                    UUID: authData.UUID,
                    access_token: authData.access_token,
                    refresh_token: authData.refresh_token,
                    expires_in: authData.expires_in,
                }, refreshStorageHandler);
                setAuth({
                    loggedIn: true,
                    UUID: authData.UUID,
                    authProvider: authProvider,
                    signOut: onSignOut,
                });
                getUserData(config.baseUrl, authProvider, setAuth);
            }
        });
    }, []);
    return (React.createElement(Fragment, null,
        React.createElement(AuthContext.Provider, { value: auth }, props.children)));
}
export function ShowWhenAuthenticated(props) {
    const { loggedIn } = useContext(AuthContext);
    return loggedIn ? React.createElement(Fragment, null, props.children) : null;
}
export function ShowWhenNotAuthenticated(props) {
    const { loggedIn } = useContext(AuthContext);
    return !loggedIn ? React.createElement(Fragment, null, props.children) : null;
}

==> ordering-core-react-1.0.0.tgz: package/lib/esm/AuthWrapper.js <==
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import React, { Fragment, useContext, useEffect, useState } from "react";
import AuthContext from "./AuthContext";
import ConfigContext from "./ConfigContext";
import * as orderingCore from "@orderingstack/ordering-core";
const refreshStorageHandler = {
    getRefreshToken: (tenant) => {
        return (window.localStorage.getItem(`orderingstack_${tenant}_refreshToken`) || "");
    },
    setRefreshToken: (tenant, token) => {
        window.localStorage.setItem(`orderingstack_${tenant}_refreshToken`, token);
    },
    clearRefreshToken: (tenant) => {
        window.localStorage.removeItem(`orderingstack_${tenant}_refreshToken`);
    },
};
export default function AuthWrapper(props) {
    const _configContext = useContext(ConfigContext);
    if (!_configContext) {
        return React.createElement(Fragment, null, "Configuration shoud be provided");
    }
    const config = _configContext;
    const [auth, setAuth] = useState({
        loggedIn: false,
        UUID: "",
    });
    function onSignOut() {
        console.log("--- log out ----");
        setAuth({ loggedIn: false, UUID: "" });
        orderingCore.clearAuthData(config.tenant, refreshStorageHandler);
    }
    function hasValidRoles(acceptedRolesArray, roles) {
        if (!acceptedRolesArray || acceptedRolesArray.length === 0) {
            return true;
        }
        const authorities = roles.map((r) => r.role);
        const rolesIntersection = acceptedRolesArray.filter((value) => authorities.includes(value));
        const isAuthorized = rolesIntersection.length > 0; //authorities.includes(role);
        return isAuthorized;
    }
    function getUserData(baseUrl, authProvider, setAuth) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const { UUID, token } = yield authProvider();
                if (token) {
                    const userData = yield orderingCore.getLoggedUserData(baseUrl, token);
                    if (!hasValidRoles(props.roles, userData.roles)) {
                        console.log("--- USER HAS NO REQUIRED ROLES ----- ");
                        onSignOut();
                    }
                    setAuth({
                        loggedIn: true,
                        email: userData.login,
                        UUID: UUID,
                        authProvider: authProvider,
                        signOut: onSignOut,
                    });
                }
            }
            catch (err) {
                onSignOut();
            }
        });
    }
    useEffect(() => {
        //console.log("AutWrapper init --- ");
        const authProvider = orderingCore.createAuthDataProvider({
            BASE_URL: config.baseUrl,
            TENANT: config.tenant,
            BASIC_AUTH: config.basicAuth,
            anonymousAuth: config.anonymousOnInit,
        }, refreshStorageHandler, false);
        // Check for refreshToken in search params
        try {
            const params = new URLSearchParams(window.location.search);
            const refreshToken = params.get("refreshToken");
            if (refreshToken) {
                refreshStorageHandler.setRefreshToken(config.tenant, refreshToken);
                // Remove refresh token from search params
                params.delete("refreshToken");
                const url = `${window.location.origin}${window.location.pathname}?${params.toString()}`;
                window.history.replaceState(null, "", url);
            }
        }
        catch (e) {
            console.warn(e);
        }
        getUserData(config.baseUrl, authProvider, setAuth);
        window.addEventListener("message", function (event) {
            if (event.origin !== config.baseUrl)
                return;
            const authData = event.data;
            console.log(authData);
            if (authData.UUID === "") {
                setAuth({ loggedIn: false, UUID: "" });
            }
            else {
                orderingCore.setAuthData(config.tenant, {
                    UUID: authData.UUID,
                    access_token: authData.access_token,
                    refresh_token: authData.refresh_token,
                    expires_in: authData.expires_in,
                }, refreshStorageHandler);
                setAuth({
                    loggedIn: true,
                    UUID: authData.UUID,
                    authProvider: authProvider,
                    signOut: onSignOut,
                });
                getUserData(config.baseUrl, authProvider, setAuth);
            }
        });
    }, []);
    return (React.createElement(Fragment, null,
        React.createElement(AuthContext.Provider, { value: auth }, props.children)));
}
export function ShowWhenAuthenticated(props) {
    const { loggedIn } = useContext(AuthContext);
    return loggedIn ? React.createElement(Fragment, null, props.children) : null;
}
export function ShowWhenNotAuthenticated(props) {
    const { loggedIn } = useContext(AuthContext);
    return !loggedIn ? React.createElement(Fragment, null, props.children) : null;
}
